var models = require('./models');

function AlphaApi(apiClient) {
    this.apiClient = apiClient;
}

/*
    Create a new changelist that can affect multiple files using different kinds of actions.
    If you require the ability to integrate or move, for example, you can use this method.

*/
AlphaApi.prototype.serverChangesPost = function serverChangesPost(server, changelistRequest, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = changelistRequest;
    this.apiClient.executeMethod('post', '/{server}/changes', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Submits a [p4gf_config](http://www.perforce.com/perforce/r15.1/manuals/git-fusion/chapter_dyn_ngj_3l.html#section_jgz_nz2_2j) file to create or update a repository configuration.

    If the repository does not exist or has been previously deleted, this method saves contents of the config file to a new `p4gf_config` file.
    If the repository has already been initialised, this method replaces all of the file contents of the specified repository's `p4gf_config` file.

*/
AlphaApi.prototype.serverGitFusionReposPost = function serverGitFusionReposPost(server, body, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = body;
    this.apiClient.executeMethod('post', '/{server}/git-fusion-repos', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Lists all configured repositories readable by the current user.
*/
AlphaApi.prototype.serverGitFusionReposGet = function serverGitFusionReposGet(server, callback) {
    var query = null;
    var pathParams = {"server": server};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/git-fusion-repos', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = null;
        if (Array.isArray(response.body)) {
            data = response.body.map(function(cur) {
                return new models.GitFusionRepoId(cur);
            });
        } else {
            throw "Expected an array, got " + (typeof response.body);
        }
        callback(null, data);
    });
};
 /*
    Deletes the repository configuration (The [p4gf_config file](http://www.perforce.com/perforce/r15.1/manuals/git-fusion/chapter_dyn_ngj_3l.html#section_jgz_nz2_2j)).
    Contents of the repository are not deleted from Perforce.

*/
AlphaApi.prototype.serverGitFusionReposRepoDelete = function serverGitFusionReposRepoDelete(server, repo, callback) {
    var query = null;
    var pathParams = {"server": server, "repo": repo};
    var body = null;
    this.apiClient.executeMethod('delete', '/{server}/git-fusion-repos/{repo}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Updates values in the repository configuration.
    This method will find all specified parameters and update each value for the specified repository's configuration file.

*/
AlphaApi.prototype.serverGitFusionReposRepoPatch = function serverGitFusionReposRepoPatch(server, repo, body, callback) {
    var query = null;
    var pathParams = {"server": server, "repo": repo};
    var body = body;
    this.apiClient.executeMethod('patch', '/{server}/git-fusion-repos/{repo}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.CommandResponse(response.body);
        callback(null, data);
    });
};
 /*
    Return configuration for the specified repository.
    Grabs and returns contents of the [p4gf_config](http://www.perforce.com/perforce/r15.1/manuals/git-fusion/chapter_dyn_ngj_3l.html#section_jgz_nz2_2j) file for given repository.

*/
AlphaApi.prototype.serverGitFusionReposRepoGet = function serverGitFusionReposRepoGet(server, repo, callback) {
    var query = null;
    var pathParams = {"server": server, "repo": repo};
    var body = null;
    this.apiClient.executeMethod('get', '/{server}/git-fusion-repos/{repo}', pathParams, query, body, function(err, response){
        if (err) {
            callback(err);
            return;
        }
        var data = new models.GitFusionRepoConfig(response.body);
        callback(null, data);
    });
};
 

module.exports = AlphaApi;
