/*
  A changelist specification.

  For more information see the [command reference](https://www.perforce.com/perforce/doc.current/manuals/cmdref/p4_change.html).

*/
function ChangeCommand(data) {

    Object.defineProperties(this, {
        /*
          Contains the changelist number if editing an existing changelist, or `new` if creating a new changelist.

        */
        "change": {
            value: data ? data.change : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Name of current client workspace
        */
        "client": {
            value: data ? data.client : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Date the changelist was last modified.
        */
        "date": {
            enumerable: true,
            get: function() {
                if (data && data.date) {
                    var strVal = data.date;
                    return Date.parse(strVal);
                }
            }
        },
        /*
          Name of the change owner.

          The owner of an empty pending changelist (that is, a pending changelist without any files in it) can transfer ownership of the changelist to another existing user either by editing this field, or by using the -U user option.

          The specified owner does not have to be a Perforce user.
          You might want to use an arbitrary name if the user does not yet exist, or if you have deleted the user and need a placeholder until you can assign the spec to a new user.

        */
        "user": {
            value: data ? data.user : undefined,
            enumerable: true,
            writable: true
        },
        /*
          `pending`, `shelved`, `submitted`, or `new`.
          Not editable by the user.

          The status is `new` when the changelist is created, `pending` when it has been created but has not yet been submitted to the depot, `shelved` when its contents are shelved, and `submitted` when its contents have been stored in the depot.

        */
        "status": {
            value: data ? data.status : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Textual description of changelist.

          If you do not have access to a restricted changelist, the description is replaced with a "no permission" message.

        */
        "description": {
            value: data ? data.description : undefined,
            enumerable: true,
            writable: true
        },
        /*
          A list of jobs that are fixed by this changelist.

        */
        "jobs": {
            value: data ? data.jobs : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Type of change: `restricted` or `public`.

          The Type: field can be used to hide the change or its description from users.
          A shelved or committed change (as denoted in the Status: field) that is restricted is accessible only to users who own the change or have list permission to at least one file in the change.

          Public changes are displayed without restrictions.

          By default, changelists are public.
          A Perforce superuser can set the default changelist type (for changelists created after the configurable is set) by setting the defaultChangeType configurable.

        */
        "type": {
            value: data ? data.type : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The list of files submitted in this changelist.

        */
        "files": {
            value: data ? data.files : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Displays the name of the user who ran the p4 fetch, p4 push, or p4 unzip command that imported this change into the server.

          This field is primarily useful for distributed versioning (DVCS) scenarios, in which changelists are copied from one server to another, and help you correlate the changelist’s basic identity as it is copied.

          In such configurations, Perforce recommends using the submit.identity configurable to enable automatic generation of changelist identities by the p4 submit.

        */
        "importedBy": {
            value: data ? data.importedBy : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Contains a label which uniquely identifies this changelist across all servers where it has been fetched, pushed, or unzipped.

          This field is primarily useful for distributed versioning (DVCS) scenarios, in which changelists are copied from one server to another, and help you correlate the changelist’s basic identity as it is copied.

          In such configurations, Perforce recommends using the submit.identity configurable to enable automatic generation of changelist identities by the p4 submit.

        */
        "identify": {
            value: data ? data.identify : undefined,
            enumerable: true,
            writable: true
        }
    });

}

module.exports = ChangeCommand;
