/*
  The depot specification, which is the shared repository Perforce stores files in.

*/
function DepotCommand(data) {

    Object.defineProperties(this, {
        /*
          The depot name.

        */
        "depot": {
            value: data ? data.depot : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The user who owns the depot.
          By default, this is the user who created the depot.

          The specified owner does not have to be a Perforce user.
          You might want to use an arbitrary name if the user does not yet exist, or if you have deleted the user and need a placeholder until you can assign the spec to a new user.

        */
        "owner": {
            value: data ? data.owner : undefined,
            enumerable: true,
            writable: true
        },
        /*
          A short description of the depot’s purpose. Optional.

        */
        "description": {
            value: data ? data.description : undefined,
            enumerable: true,
            writable: true
        },
        /*
          `local`, `remote`, `spec`, `stream`, `unload`, `archive` or `tangent`.

          A local depot is writable, and is the default depot type.
          Files reside in the server's root directory and are managed directly by the server.

          A stream depot is also writable, but contains streams, a type of branch that includes hierarchy and policy.

          A remote depot references files that reside on other servers, and cannot be written to.

          The spec depot, if present, automatically archives edited forms.

          The unload depot, if present, holds infrequently-used metadata (about old client workspaces and labels) that has been unloaded with the p4 unload command.

          An archive depot is used in conjunction with the p4 archive and p4 restore commands to facilitate offline (or near-line) storage of infrequently-accessed revisions, typically large binaries.

          A tangent depot defines a read-only location that holds tangents created by the p4 fetch -t command.
          The tangent depot named tangent is automatically created by p4 fetch -t if one does not already exist.

        */
        "type": {
            value: data ? data.type : undefined,
            enumerable: true,
            writable: true
        },
        /*
          If the `Type:` is `remote`, the address should be the P4PORT address of the remote server.
          If the `Type:` is local or spec, this field is ignored.

        */
        "address": {
            value: data ? data.address : undefined,
            enumerable: true,
            writable: true
        },
        /*
          If the Type: is spec, this field holds an optional suffix for generated paths to objects in the spec depot.

          The default suffix is .p4s.
          You do not need a suffix to use the spec depot, but supplying a file extension to your Perforce server’s versioned specs enables users of GUI client software to associate Perforce specifications with a preferred text editor.
          If the Type: is local or remote, this field is ignored.

        */
        "suffix": {
            value: data ? data.suffix : undefined,
            enumerable: true,
            writable: true
        },
        /*
          For stream depots, the optional depth to be used for stream paths in the depot, where depth specifies the number of slashes following the depot name of a stream. ]

          This field is used when streams are being created.
          The default is 1, matching the traditional stream name.
          You cannot update this value once streams or archive data exist in a depot.

        */
        "streamDepth": {
            value: data ? data.streamDepth : undefined,
            enumerable: true,
            writable: true
        },
        /*
          If the Type: is local, spec, or archive, set the map to point to the relative location of the depot subdirectory.
          The map must contain the `...` wildcard; for example, a local depot new might have a Map: of `new/...`.

          If the Type: is remote, set the map to point to a location in the remote depot's physical namespace, for example, `//depot/new/rel2/...`.
          This directory will be the root of the local representation of the remote depot.

        */
        "map": {
            value: data ? data.map : undefined,
            enumerable: true,
            writable: true
        },
        /*
          For spec depots, an optional description of which specs should be saved, expressed as a view.

        */
        "specMap": {
            value: data ? data.specMap : undefined,
            enumerable: true,
            writable: true
        }
    });

}

module.exports = DepotCommand;
