/*
  Defines the triggers table, like it would appear in the output to the `p4 triggers` command.

*/
function Triggers(data) {

    Object.defineProperties(this, {
        /*
          A list of trigger definitions.

          A trigger definition contains four fields that specify the name of the trigger, the type of event that should trigger the execution of the script, the paths that should be affected by the trigger, the location of the script, and other trigger type-dependent information.
          When the condition specified in a trigger definition is satisfied, the associated script or program is executed.

          Example: `trig1 change-submit //depot/dir/...   "/usr/bin/s1.pl %changelist%"`

          See the Helix Versioning Engine Administrator Guide for more details on trigger definitions.

        */
        "triggers": {
            value: data ? data.triggers : undefined,
            enumerable: true,
            writable: true
        }
    });

}

module.exports = Triggers;
